From 424389dc1c2b5d112891ea119e2cb40beaf6dc2f Mon Sep 17 00:00:00 2001
From: Prafulla Wadaskar <prafulla@pe-lt078.(none)>
Date: Mon, 19 Jul 2010 18:27:23 +0530
Subject: [PATCH 2/2] Kirkwood: openrd_base: Added SATA support

Signed-off-by: Prafulla Wadaskar <prafulla@pe-lt078.(none)>
---
 board/Marvell/openrd_base/openrd_base.c |   11 ++++++++
 board/Marvell/openrd_base/openrd_base.h |    2 +
 include/configs/openrd_base.h           |   40 ++++++++++++++++++++++++++++++-
 3 files changed, 52 insertions(+), 1 deletions(-)

diff --git a/board/Marvell/openrd_base/openrd_base.c b/board/Marvell/openrd_base/openrd_base.c
index c00a08a..3c4c85d 100644
--- a/board/Marvell/openrd_base/openrd_base.c
+++ b/board/Marvell/openrd_base/openrd_base.c
@@ -110,6 +110,17 @@ int board_init(void)
 
 	/* adress of boot parameters */
 	gd->bd->bi_boot_params = kw_sdram_bar(0) + 0x100;
+
+#if defined(CONFIG_MVSATA_IDE)
+	/* Enable SATA port 0 if SATA IDE was configured */
+	mvsata_ide_initialize_port(
+		(struct mv_sata_port_registers *)
+		(KW_SATA_BASE + KW_SATA_PORT0_OFFSET));
+	mvsata_ide_initialize_port(
+		(struct mv_sata_port_registers *)
+		(KW_SATA_BASE + KW_SATA_PORT1_OFFSET));
+#endif
+
 	return 0;
 }
 
diff --git a/board/Marvell/openrd_base/openrd_base.h b/board/Marvell/openrd_base/openrd_base.h
index f3daf17..ffe2917 100644
--- a/board/Marvell/openrd_base/openrd_base.h
+++ b/board/Marvell/openrd_base/openrd_base.h
@@ -30,6 +30,8 @@
 #ifndef __OPENRD_BASE_H
 #define __OPENRD_BASE_H
 
+#define __io	/* __io is necessary for cmd_ide to compile */
+
 #define OPENRD_OE_LOW		(~(1<<28))        /* RS232 / RS485 */
 #define OPENRD_OE_HIGH		(~(1<<2))         /* SD / UART1 */
 #define OPENRD_OE_VAL_LOW		(0)       /* Sel RS232 */
diff --git a/include/configs/openrd_base.h b/include/configs/openrd_base.h
index d2f4502..3362b57 100644
--- a/include/configs/openrd_base.h
+++ b/include/configs/openrd_base.h
@@ -100,9 +100,10 @@
 #define CONFIG_CMD_DHCP
 #define CONFIG_CMD_ENV
 #define CONFIG_CMD_MII
-#define CONFIG_CMD_NAND
+//#define CONFIG_CMD_NAND
 #define CONFIG_CMD_PING
 #define CONFIG_CMD_USB
+#define CONFIG_CMD_IDE
 
 /*
  * NAND configuration
@@ -205,6 +206,43 @@
 #endif /* CONFIG_CMD_USB */
 
 /*
+ * IDe Support on SATA port0
+ */
+#ifdef CONFIG_CMD_IDE
+#define __io
+#define CONFIG_CMD_EXT2
+#define CONFIG_MVSATA_IDE
+#define CONFIG_MVSATA_IDE_USE_PORT1
+
+/* Needs byte-swapping for ATA data register */
+#define CONFIG_IDE_SWAP_IO
+
+/* Data, registers and alternate blocks are at the same offset */
+#define CONFIG_SYS_ATA_DATA_OFFSET	(0x0100)
+#define CONFIG_SYS_ATA_REG_OFFSET	(0x0100)
+#define CONFIG_SYS_ATA_ALT_OFFSET	(0x0100)
+
+/* Each 8-bit ATA register is aligned to a 4-bytes address */
+#define CONFIG_SYS_ATA_STRIDE		4
+
+/* Controller supports 48-bits LBA addressing */
+#define CONFIG_LBA48
+
+/*
+ * CONFIG_CMD_IDE requires some #defines for ATA registers
+ */
+
+/* A single bus, a single device */
+#define CONFIG_SYS_IDE_MAXBUS		2
+#define CONFIG_SYS_IDE_MAXDEVICE	2
+/* ATA registers base is at SATA controller base */
+#define CONFIG_SYS_ATA_BASE_ADDR	KW_SATA_BASE
+/* ATA bus 0 is orion5x port 1 on ED Mini V2 */
+#define CONFIG_SYS_ATA_IDE0_OFFSET	KW_SATA_PORT0_OFFSET
+#define CONFIG_SYS_ATA_IDE1_OFFSET	KW_SATA_PORT1_OFFSET
+
+#endif /* CONFIG_CMD_IDE */
+/*
  * File system
  */
 #define CONFIG_CMD_FAT
-- 
1.7.0.1

